#! /bin/bash
#
# Time-stamp: <2003-08-01 21:01:57 zaykin> (written by Dmitri Zaykin)

set -o nounset +o noclobber

### Set working directory
Cdir=.

if [ $# != 4 ]; then
   echo "Haplotype/disease association using sliding window of markers"
   echo ""
   echo "The following parameters should be supplied to the script"
   echo ""
   echo "data file name (a file with affection value followed by genotype info, 2 cols per locus)"
   echo "header file name (a file with one line of marker names)"
   echo "window size (e.g. 3)"
   echo "missing data value (e.g. 0)"
   echo ""
   echo "Example: " $0 "mydat header 3 0 > outfile"
   exit 1
fi

# The following parameters should be supplied to the script

      DataFile=$1
    headerfile=$2
declare -i wnd=$3
       missing=$4
      num_runs=0

############ "built-in" parameters ############
restarts=11       # E-M restarts (must be an odd number or Y and X go to output) 
tolerance=0.001   # E-M convergence precision

locinames=($(cat $headerfile))
declare -i i=2 n=$($Cdir/cntcols.x < $DataFile)
declare -i quant=$(gawk '{print $1; exit 0}' < $DataFile | perl -ne 'if($_ =~ /\./){print}' | wc -w)
declare -i mn=${#locinames[@]}*2

if [ $n -ne $((mn+1)) ]; then
    echo number of loci names in $headerfile does not match columns in $DataFile
    exit 1
fi

while [ $i -le $((n-$((wnd*2))+1)) ]; do
    declare -i j=i jn=$((i+wnd*2))
    declare -i j2=$(((i-1)/2)) jn2=$(((i-1)/2+wnd))
    while [ $j2 -lt $jn2 ]; do
	setlo[$j2]=${locinames[j2]}
	let j2+=1
    done
    while [ $j -lt $jn ]; do
	setj[$((j-i))]=$j
	let j+=1
    done
    let i+=2
    Seed=$RANDOM
    echo ""
    echo LociSet ${setlo[@]}
    echo ""
    TmpFile=$Cdir/emgi.$Seed.$wnd.tmp
    $Cdir/pcols.x 1 ${setj[@]} < $DataFile > $TmpFile
    $Cdir/emgi.x $restarts $tolerance $missing $TmpFile $num_runs $Seed
    rm $TmpFile
    setlo=()
done
